﻿
using System;
using System.Windows.Forms;

namespace CSharpDemo
{
    partial class FilterDemo 
    {
        /// <summary>
        /// Required designer variable.
        /// </summary>
        private System.ComponentModel.IContainer components = null;

        private MessageInfo messageInfo = null;
        private ConfigSetting configSetting = null;
        private FilterTest filterTest = null;

        /// <summary>
        /// Clean up any resources being used.
        /// </summary>
        /// <param name="disposing">true if managed resources should be disposed; otherwise, false.</param>
        protected override void Dispose(bool disposing)
        {
            if (disposing && (components != null))
            {
                components.Dispose();
            }

            if (disposing && (null != messageInfo))
            {
                messageInfo.Dispose();
            }

            base.Dispose(disposing);
        }

        #region Config setting

        void InitConfig()
        {
            messageInfo = new MessageInfo(listView_MessageInfo);
            configSetting = new ConfigSetting(listView_FilterRules);
            filterTest = new FilterTest();
            EventMessage.SetListViewMessage(listView_Message);            

            textBox_ConnectionTimeout.Text = configSetting.ConnectionTimeOut.ToString();
            textBox_ExcludePID.Text = System.Diagnostics.Process.GetCurrentProcess().Id.ToString() + ";";
            textBox_ConnectionThreads.Text = configSetting.FilterConnectionThreads.ToString();
            textBox_AccessFlag.Text = ((uint)EaseFilter.ALLOW_MAX_RIGHT_ACCESS).ToString();
            textBox_RequestRegistration.Text = configSetting.RequestRegistration.ToString();

        }

        void SendConfigInfoToFilter()
        {
            if (!EaseFilter.IsFilterStarted)
            {
                System.Windows.Forms.MessageBox.Show("Filter is not started yet.");
                return;
            }

            EaseFilter.ResetConfigData();

            EaseFilter.SetConnectionTimeout(configSetting.ConnectionTimeOut);
            EaseFilter.SetFilterType((uint)configSetting.FilterType);

            System.Collections.Generic.List<ConfigSetting.FilterRule> filterRuleList = configSetting.FilterList;
            foreach (ConfigSetting.FilterRule filterRule in filterRuleList)
            {
                EaseFilter.AddFilterRule((uint)filterRule.AccessFlag, filterRule.FilterMask, filterRule.ReparseMask);
            }

            foreach (uint excludedPid in configSetting.ExcludedPid)
            {
                EaseFilter.AddExcludedProcessId(excludedPid);
            }

            EaseFilter.RegisterIoRequest(configSetting.RequestRegistration);

        }

        private void button_AddFilterRule_Click(object sender, EventArgs e)
        {
            EaseFilter.AccessFlag accessFlag = (EaseFilter.AccessFlag)uint.Parse(textBox_AccessFlag.Text);

            if (!configSetting.AddFilterRule(accessFlag, textBox_FilterMask.Text, textBox_ReparseMask.Text))
            {
                System.Windows.Forms.MessageBox.Show("Filter rule already exist.");
            }
        }

        private void button_RemoveFilter_Click(object sender, EventArgs e)
        {
            foreach (System.Windows.Forms.ListViewItem item in listView_FilterRules.SelectedItems)
            {
                configSetting.RemoveFilterRule(item);
            }
        }


        private void button_ExcludedPID_Click(object sender, EventArgs e)
        {
            OptionForm optionForm = new OptionForm(OptionForm.OptionType.Excluded_ProccessId, textBox_ExcludePID.Text);
            if (System.Windows.Forms.DialogResult.OK == optionForm.ShowDialog())
            {
                textBox_ExcludePID.Text = optionForm.ExcludedPid;
            }
            optionForm.Close();

        }

        private void button_RequestRegistration_Click(object sender, EventArgs e)
        {
            OptionForm optionForm = new OptionForm(OptionForm.OptionType.Register_Request, textBox_RequestRegistration.Text);
            if (System.Windows.Forms.DialogResult.OK == optionForm.ShowDialog())
            {
                textBox_RequestRegistration.Text = optionForm.RequestRegistration.ToString();
            }
            optionForm.Close();
        }

        private void button_AccessFlag_Click(object sender, EventArgs e)
        {
            OptionForm optionForm = new OptionForm(OptionForm.OptionType.Access_Flag, textBox_AccessFlag.Text);
            if (System.Windows.Forms.DialogResult.OK == optionForm.ShowDialog())
            {
                textBox_AccessFlag.Text = optionForm.AccessFlags.ToString();
            }
            optionForm.Close();

        }


        private void button_ApplySetting_Click(object sender, EventArgs e)
        {
            configSetting.ConnectionTimeOut = uint.Parse(textBox_ConnectionTimeout.Text);
            configSetting.RequestRegistration = uint.Parse(textBox_RequestRegistration.Text);
            configSetting.FilterType = (EaseFilter.FilterType)comboBox_FilterType.SelectedIndex;
            configSetting.FilterConnectionThreads = uint.Parse(textBox_ConnectionThreads.Text);

            System.Collections.Generic.List<uint> pidList = new System.Collections.Generic.List<uint>();

            string[] pids = textBox_ExcludePID.Text.Split(';');
            foreach (string pid in pids)
            {
                if (!string.IsNullOrEmpty(pid))
                {
                    pidList.Add(uint.Parse(pid));
                }
            }

            configSetting.ExcludedPid = pidList;

            if (EaseFilter.IsFilterStarted)
            {
                SendConfigInfoToFilter();
            }
        }

        #endregion

        #region Windows Form Designer generated code

        /// <summary>
        /// Required method for Designer support - do not modify
        /// the contents of this method with the code editor.
        /// </summary>
        private void InitializeComponent()
        {
         
            this.TabPage = new System.Windows.Forms.TabControl();
            this.tabPage_FilterMessage = new System.Windows.Forms.TabPage();
            this.splitContainer1 = new System.Windows.Forms.SplitContainer();
            this.listView_MessageInfo = new System.Windows.Forms.ListView();
            this.groupBox1 = new System.Windows.Forms.GroupBox();
            this.button_UnInstallDriver = new System.Windows.Forms.Button();
            this.button_InstallDriver = new System.Windows.Forms.Button();
            this.button_Clear = new System.Windows.Forms.Button();
            this.button_Start = new System.Windows.Forms.Button();
            this.button_Stop = new System.Windows.Forms.Button();
            this.tabPage_Setting = new System.Windows.Forms.TabPage();
            this.splitContainer3 = new System.Windows.Forms.SplitContainer();
            this.splitContainer4 = new System.Windows.Forms.SplitContainer();
            this.button_RequestRegistration = new System.Windows.Forms.Button();
            this.textBox_RequestRegistration = new System.Windows.Forms.TextBox();
            this.textBox_ConnectionThreads = new System.Windows.Forms.TextBox();
            this.label_ConnectionThreads = new System.Windows.Forms.Label();
            this.button_ExcludedPID = new System.Windows.Forms.Button();
            this.comboBox_FilterType = new System.Windows.Forms.ComboBox();
            this.groupBox3 = new System.Windows.Forms.GroupBox();
            this.label7 = new System.Windows.Forms.Label();
            this.textBox_ReparseMask = new System.Windows.Forms.TextBox();
            this.button_AccessFlag = new System.Windows.Forms.Button();
            this.textBox_FilterMask = new System.Windows.Forms.TextBox();
            this.label6 = new System.Windows.Forms.Label();
            this.label5 = new System.Windows.Forms.Label();
            this.textBox_AccessFlag = new System.Windows.Forms.TextBox();
            this.textBox_ExcludePID = new System.Windows.Forms.TextBox();
            this.textBox_ConnectionTimeout = new System.Windows.Forms.TextBox();
            this.label4 = new System.Windows.Forms.Label();
            this.label3 = new System.Windows.Forms.Label();
            this.label2 = new System.Windows.Forms.Label();
            this.label1 = new System.Windows.Forms.Label();
            this.listView_FilterRules = new System.Windows.Forms.ListView();
            this.button_ApplySetting = new System.Windows.Forms.Button();
            this.button_RemoveFilter = new System.Windows.Forms.Button();
            this.button_AddFilterRule = new System.Windows.Forms.Button();
            this.tabPage_EventLog = new System.Windows.Forms.TabPage();
            this.listView_Message = new System.Windows.Forms.ListView();
            this.TabPage.SuspendLayout();
            this.tabPage_FilterMessage.SuspendLayout();
            this.splitContainer1.Panel1.SuspendLayout();
            this.splitContainer1.Panel2.SuspendLayout();
            this.splitContainer1.SuspendLayout();
            this.groupBox1.SuspendLayout();
            this.tabPage_Setting.SuspendLayout();
            this.splitContainer3.Panel1.SuspendLayout();
            this.splitContainer3.Panel2.SuspendLayout();
            this.splitContainer3.SuspendLayout();
            this.splitContainer4.Panel1.SuspendLayout();
            this.splitContainer4.Panel2.SuspendLayout();
            this.splitContainer4.SuspendLayout();
            this.groupBox3.SuspendLayout();
            this.tabPage_EventLog.SuspendLayout();
            this.SuspendLayout();
            // 
            // TabPage
            // 
            this.TabPage.Controls.Add(this.tabPage_FilterMessage);
            this.TabPage.Controls.Add(this.tabPage_Setting);
            this.TabPage.Controls.Add(this.tabPage_EventLog);
            this.TabPage.Dock = System.Windows.Forms.DockStyle.Fill;
            this.TabPage.Location = new System.Drawing.Point(0, 0);
            this.TabPage.Name = "TabPage";
            this.TabPage.SelectedIndex = 0;
            this.TabPage.Size = new System.Drawing.Size(1018, 518);
            this.TabPage.TabIndex = 3;
            // 
            // tabPage_FilterMessage
            // 
            this.tabPage_FilterMessage.Controls.Add(this.splitContainer1);
            this.tabPage_FilterMessage.Location = new System.Drawing.Point(4, 22);
            this.tabPage_FilterMessage.Name = "tabPage_FilterMessage";
            this.tabPage_FilterMessage.Padding = new System.Windows.Forms.Padding(3);
            this.tabPage_FilterMessage.Size = new System.Drawing.Size(1010, 492);
            this.tabPage_FilterMessage.TabIndex = 0;
            this.tabPage_FilterMessage.Text = "Filter Message";
            this.tabPage_FilterMessage.UseVisualStyleBackColor = true;
            // 
            // splitContainer1
            // 
            this.splitContainer1.Dock = System.Windows.Forms.DockStyle.Fill;
            this.splitContainer1.Location = new System.Drawing.Point(3, 3);
            this.splitContainer1.Name = "splitContainer1";
            this.splitContainer1.Orientation = System.Windows.Forms.Orientation.Horizontal;
            // 
            // splitContainer1.Panel1
            // 
            this.splitContainer1.Panel1.Controls.Add(this.listView_MessageInfo);
            // 
            // splitContainer1.Panel2
            // 
            this.splitContainer1.Panel2.Controls.Add(this.groupBox1);
            this.splitContainer1.Panel2MinSize = 50;
            this.splitContainer1.Size = new System.Drawing.Size(1004, 486);
            this.splitContainer1.SplitterDistance = 432;
            this.splitContainer1.TabIndex = 5;
            // 
            // listView_MessageInfo
            // 
            this.listView_MessageInfo.Dock = System.Windows.Forms.DockStyle.Fill;
            this.listView_MessageInfo.FullRowSelect = true;
            this.listView_MessageInfo.GridLines = true;
            this.listView_MessageInfo.HideSelection = false;
            this.listView_MessageInfo.LabelEdit = true;
            this.listView_MessageInfo.Location = new System.Drawing.Point(0, 0);
            this.listView_MessageInfo.MultiSelect = false;
            this.listView_MessageInfo.Name = "listView_MessageInfo";
            this.listView_MessageInfo.ShowItemToolTips = true;
            this.listView_MessageInfo.Size = new System.Drawing.Size(1004, 432);
            this.listView_MessageInfo.TabIndex = 3;
            this.listView_MessageInfo.UseCompatibleStateImageBehavior = false;
            this.listView_MessageInfo.View = System.Windows.Forms.View.Details;
            // 
            // groupBox1
            // 
            this.groupBox1.Controls.Add(this.button_UnInstallDriver);
            this.groupBox1.Controls.Add(this.button_InstallDriver);
            this.groupBox1.Controls.Add(this.button_Clear);
            this.groupBox1.Controls.Add(this.button_Start);
            this.groupBox1.Controls.Add(this.button_Stop);
            this.groupBox1.Dock = System.Windows.Forms.DockStyle.Fill;
            this.groupBox1.Location = new System.Drawing.Point(0, 0);
            this.groupBox1.Name = "groupBox1";
            this.groupBox1.Size = new System.Drawing.Size(1004, 50);
            this.groupBox1.TabIndex = 4;
            this.groupBox1.TabStop = false;
            // 
            // button_UnInstallDriver
            // 
            this.button_UnInstallDriver.Location = new System.Drawing.Point(790, 13);
            this.button_UnInstallDriver.Name = "button_UnInstallDriver";
            this.button_UnInstallDriver.Size = new System.Drawing.Size(86, 23);
            this.button_UnInstallDriver.TabIndex = 4;
            this.button_UnInstallDriver.Text = "UnInstallDriver";
            this.button_UnInstallDriver.UseVisualStyleBackColor = true;
            this.button_UnInstallDriver.Click += new System.EventHandler(this.button_UnInstallDriver_Click);
            // 
            // button_InstallDriver
            // 
            this.button_InstallDriver.Location = new System.Drawing.Point(62, 13);
            this.button_InstallDriver.Name = "button_InstallDriver";
            this.button_InstallDriver.Size = new System.Drawing.Size(75, 23);
            this.button_InstallDriver.TabIndex = 3;
            this.button_InstallDriver.Text = "InstallDriver";
            this.button_InstallDriver.UseVisualStyleBackColor = true;
            this.button_InstallDriver.Click += new System.EventHandler(this.button_InstallDriver_Click);
            // 
            // button_Clear
            // 
            this.button_Clear.Location = new System.Drawing.Point(560, 13);
            this.button_Clear.Name = "button_Clear";
            this.button_Clear.Size = new System.Drawing.Size(124, 23);
            this.button_Clear.TabIndex = 2;
            this.button_Clear.Text = "Clear Message";
            this.button_Clear.UseVisualStyleBackColor = true;
            this.button_Clear.Click += new System.EventHandler(this.button_Clear_Click);
            // 
            // button_Start
            // 
            this.button_Start.Location = new System.Drawing.Point(223, 13);
            this.button_Start.Name = "button_Start";
            this.button_Start.Size = new System.Drawing.Size(91, 23);
            this.button_Start.TabIndex = 0;
            this.button_Start.Text = "Start Filter";
            this.button_Start.UseVisualStyleBackColor = true;
            this.button_Start.Click += new System.EventHandler(this.button_Start_Click);
            // 
            // button_Stop
            // 
            this.button_Stop.Location = new System.Drawing.Point(378, 13);
            this.button_Stop.Name = "button_Stop";
            this.button_Stop.Size = new System.Drawing.Size(75, 23);
            this.button_Stop.TabIndex = 1;
            this.button_Stop.Text = "Stop Filter";
            this.button_Stop.UseVisualStyleBackColor = true;
            this.button_Stop.Click += new System.EventHandler(this.button_Stop_Click);
            // 
            // tabPage_Setting
            // 
            this.tabPage_Setting.Controls.Add(this.splitContainer3);
            this.tabPage_Setting.Location = new System.Drawing.Point(4, 22);
            this.tabPage_Setting.Name = "tabPage_Setting";
            this.tabPage_Setting.Padding = new System.Windows.Forms.Padding(3);
            this.tabPage_Setting.Size = new System.Drawing.Size(1010, 492);
            this.tabPage_Setting.TabIndex = 1;
            this.tabPage_Setting.Text = "Filter Setting";
            this.tabPage_Setting.UseVisualStyleBackColor = true;
            // 
            // splitContainer3
            // 
            this.splitContainer3.Dock = System.Windows.Forms.DockStyle.Fill;
            this.splitContainer3.Location = new System.Drawing.Point(3, 3);
            this.splitContainer3.Name = "splitContainer3";
            // 
            // splitContainer3.Panel1
            // 
            this.splitContainer3.Panel1.Controls.Add(this.splitContainer4);
            // 
            // splitContainer3.Panel2
            // 
            this.splitContainer3.Panel2.Controls.Add(this.button_ApplySetting);
            this.splitContainer3.Panel2.Controls.Add(this.button_RemoveFilter);
            this.splitContainer3.Panel2.Controls.Add(this.button_AddFilterRule);
            this.splitContainer3.Size = new System.Drawing.Size(1004, 486);
            this.splitContainer3.SplitterDistance = 825;
            this.splitContainer3.TabIndex = 1;
            // 
            // splitContainer4
            // 
            this.splitContainer4.Dock = System.Windows.Forms.DockStyle.Fill;
            this.splitContainer4.Location = new System.Drawing.Point(0, 0);
            this.splitContainer4.Name = "splitContainer4";
            // 
            // splitContainer4.Panel1
            // 
            this.splitContainer4.Panel1.Controls.Add(this.button_RequestRegistration);
            this.splitContainer4.Panel1.Controls.Add(this.textBox_RequestRegistration);
            this.splitContainer4.Panel1.Controls.Add(this.textBox_ConnectionThreads);
            this.splitContainer4.Panel1.Controls.Add(this.label_ConnectionThreads);
            this.splitContainer4.Panel1.Controls.Add(this.button_ExcludedPID);
            this.splitContainer4.Panel1.Controls.Add(this.comboBox_FilterType);
            this.splitContainer4.Panel1.Controls.Add(this.groupBox3);
            this.splitContainer4.Panel1.Controls.Add(this.textBox_ExcludePID);
            this.splitContainer4.Panel1.Controls.Add(this.textBox_ConnectionTimeout);
            this.splitContainer4.Panel1.Controls.Add(this.label4);
            this.splitContainer4.Panel1.Controls.Add(this.label3);
            this.splitContainer4.Panel1.Controls.Add(this.label2);
            this.splitContainer4.Panel1.Controls.Add(this.label1);
            // 
            // splitContainer4.Panel2
            // 
            this.splitContainer4.Panel2.Controls.Add(this.listView_FilterRules);
            this.splitContainer4.Size = new System.Drawing.Size(825, 486);
            this.splitContainer4.SplitterDistance = 526;
            this.splitContainer4.TabIndex = 1;
            // 
            // button_RequestRegistration
            // 
            this.button_RequestRegistration.Location = new System.Drawing.Point(467, 140);
            this.button_RequestRegistration.Name = "button_RequestRegistration";
            this.button_RequestRegistration.Size = new System.Drawing.Size(30, 23);
            this.button_RequestRegistration.TabIndex = 21;
            this.button_RequestRegistration.Text = "...";
            this.button_RequestRegistration.UseVisualStyleBackColor = true;
            this.button_RequestRegistration.Click += new System.EventHandler(this.button_RequestRegistration_Click);
            // 
            // textBox_RequestRegistration
            // 
            this.textBox_RequestRegistration.Location = new System.Drawing.Point(190, 140);
            this.textBox_RequestRegistration.Name = "textBox_RequestRegistration";
            this.textBox_RequestRegistration.Size = new System.Drawing.Size(271, 20);
            this.textBox_RequestRegistration.TabIndex = 20;
            this.textBox_RequestRegistration.Text = "0";
            // 
            // textBox_ConnectionThreads
            // 
            this.textBox_ConnectionThreads.Location = new System.Drawing.Point(190, 66);
            this.textBox_ConnectionThreads.Name = "textBox_ConnectionThreads";
            this.textBox_ConnectionThreads.Size = new System.Drawing.Size(271, 20);
            this.textBox_ConnectionThreads.TabIndex = 15;
            this.textBox_ConnectionThreads.Text = "5";
            // 
            // label_ConnectionThreads
            // 
            this.label_ConnectionThreads.AutoSize = true;
            this.label_ConnectionThreads.Location = new System.Drawing.Point(28, 73);
            this.label_ConnectionThreads.Name = "label_ConnectionThreads";
            this.label_ConnectionThreads.Size = new System.Drawing.Size(128, 13);
            this.label_ConnectionThreads.TabIndex = 11;
            this.label_ConnectionThreads.Text = "Filter Connection Threads";
            // 
            // button_ExcludedPID
            // 
            this.button_ExcludedPID.Location = new System.Drawing.Point(467, 101);
            this.button_ExcludedPID.Name = "button_ExcludedPID";
            this.button_ExcludedPID.Size = new System.Drawing.Size(30, 23);
            this.button_ExcludedPID.TabIndex = 10;
            this.button_ExcludedPID.Text = "...";
            this.button_ExcludedPID.UseVisualStyleBackColor = true;
            this.button_ExcludedPID.Click += new System.EventHandler(this.button_ExcludedPID_Click);
            // 
            // comboBox_FilterType
            // 
            this.comboBox_FilterType.FormattingEnabled = true;
            this.comboBox_FilterType.Items.AddRange(new object[] {
            "File System Monitor Filter",
            "File System Control Filter"});
            this.comboBox_FilterType.Location = new System.Drawing.Point(190, 3);
            this.comboBox_FilterType.Name = "comboBox_FilterType";
            this.comboBox_FilterType.Size = new System.Drawing.Size(271, 21);
            this.comboBox_FilterType.TabIndex = 9;
            this.comboBox_FilterType.Text = "File System Monitor Filter";
            // 
            // groupBox3
            // 
            this.groupBox3.Controls.Add(this.label7);
            this.groupBox3.Controls.Add(this.textBox_ReparseMask);
            this.groupBox3.Controls.Add(this.button_AccessFlag);
            this.groupBox3.Controls.Add(this.textBox_FilterMask);
            this.groupBox3.Controls.Add(this.label6);
            this.groupBox3.Controls.Add(this.label5);
            this.groupBox3.Controls.Add(this.textBox_AccessFlag);
            this.groupBox3.Location = new System.Drawing.Point(0, 191);
            this.groupBox3.Name = "groupBox3";
            this.groupBox3.Size = new System.Drawing.Size(520, 142);
            this.groupBox3.TabIndex = 8;
            this.groupBox3.TabStop = false;
            this.groupBox3.Text = "Filter Rule";
            // 
            // label7
            // 
            this.label7.AutoSize = true;
            this.label7.Location = new System.Drawing.Point(25, 103);
            this.label7.Name = "label7";
            this.label7.Size = new System.Drawing.Size(101, 13);
            this.label7.TabIndex = 21;
            this.label7.Text = "Reparse Filter Mask";
            // 
            // textBox_ReparseMask
            // 
            this.textBox_ReparseMask.Location = new System.Drawing.Point(187, 96);
            this.textBox_ReparseMask.Name = "textBox_ReparseMask";
            this.textBox_ReparseMask.Size = new System.Drawing.Size(271, 20);
            this.textBox_ReparseMask.TabIndex = 20;
            this.textBox_ReparseMask.Text = "c:\\Reparse*";
            // 
            // button_AccessFlag
            // 
            this.button_AccessFlag.Location = new System.Drawing.Point(464, 28);
            this.button_AccessFlag.Name = "button_AccessFlag";
            this.button_AccessFlag.Size = new System.Drawing.Size(30, 23);
            this.button_AccessFlag.TabIndex = 10;
            this.button_AccessFlag.Text = "...";
            this.button_AccessFlag.UseVisualStyleBackColor = true;
            this.button_AccessFlag.Click += new System.EventHandler(this.button_AccessFlag_Click);
            // 
            // textBox_FilterMask
            // 
            this.textBox_FilterMask.Location = new System.Drawing.Point(187, 60);
            this.textBox_FilterMask.Name = "textBox_FilterMask";
            this.textBox_FilterMask.Size = new System.Drawing.Size(271, 20);
            this.textBox_FilterMask.TabIndex = 5;
            this.textBox_FilterMask.Text = "c:\\Test*";
            // 
            // label6
            // 
            this.label6.AutoSize = true;
            this.label6.Location = new System.Drawing.Point(25, 67);
            this.label6.Name = "label6";
            this.label6.Size = new System.Drawing.Size(58, 13);
            this.label6.TabIndex = 1;
            this.label6.Text = "Filter Mask";
            // 
            // label5
            // 
            this.label5.AutoSize = true;
            this.label5.Location = new System.Drawing.Point(25, 33);
            this.label5.Name = "label5";
            this.label5.Size = new System.Drawing.Size(62, 13);
            this.label5.TabIndex = 0;
            this.label5.Text = "AccessFlag";
            // 
            // textBox_AccessFlag
            // 
            this.textBox_AccessFlag.Location = new System.Drawing.Point(187, 30);
            this.textBox_AccessFlag.Name = "textBox_AccessFlag";
            this.textBox_AccessFlag.Size = new System.Drawing.Size(271, 20);
            this.textBox_AccessFlag.TabIndex = 4;
            this.textBox_AccessFlag.Text = "65535";
            // 
            // textBox_ExcludePID
            // 
            this.textBox_ExcludePID.Location = new System.Drawing.Point(190, 103);
            this.textBox_ExcludePID.Name = "textBox_ExcludePID";
            this.textBox_ExcludePID.Size = new System.Drawing.Size(271, 20);
            this.textBox_ExcludePID.TabIndex = 7;
            // 
            // textBox_ConnectionTimeout
            // 
            this.textBox_ConnectionTimeout.Location = new System.Drawing.Point(190, 31);
            this.textBox_ConnectionTimeout.Name = "textBox_ConnectionTimeout";
            this.textBox_ConnectionTimeout.Size = new System.Drawing.Size(271, 20);
            this.textBox_ConnectionTimeout.TabIndex = 5;
            this.textBox_ConnectionTimeout.Text = "30";
            // 
            // label4
            // 
            this.label4.AutoSize = true;
            this.label4.Location = new System.Drawing.Point(28, 106);
            this.label4.Name = "label4";
            this.label4.Size = new System.Drawing.Size(104, 13);
            this.label4.TabIndex = 3;
            this.label4.Text = "Excluded Process Id";
            // 
            // label3
            // 
            this.label3.AutoSize = true;
            this.label3.Location = new System.Drawing.Point(28, 140);
            this.label3.Name = "label3";
            this.label3.Size = new System.Drawing.Size(94, 13);
            this.label3.TabIndex = 2;
            this.label3.Text = "Register Requests";
            // 
            // label2
            // 
            this.label2.AutoSize = true;
            this.label2.Location = new System.Drawing.Point(28, 11);
            this.label2.Name = "label2";
            this.label2.Size = new System.Drawing.Size(56, 13);
            this.label2.TabIndex = 1;
            this.label2.Text = "Filter Type";
            // 
            // label1
            // 
            this.label1.AutoSize = true;
            this.label1.Location = new System.Drawing.Point(28, 34);
            this.label1.Name = "label1";
            this.label1.Size = new System.Drawing.Size(153, 13);
            this.label1.TabIndex = 0;
            this.label1.Text = "Connection Timeout (Seconds)";
            // 
            // listView_FilterRules
            // 
            this.listView_FilterRules.Dock = System.Windows.Forms.DockStyle.Fill;
            this.listView_FilterRules.FullRowSelect = true;
            this.listView_FilterRules.LabelEdit = true;
            this.listView_FilterRules.Location = new System.Drawing.Point(0, 0);
            this.listView_FilterRules.Name = "listView_FilterRules";
            this.listView_FilterRules.Size = new System.Drawing.Size(295, 486);
            this.listView_FilterRules.TabIndex = 0;
            this.listView_FilterRules.UseCompatibleStateImageBehavior = false;
            this.listView_FilterRules.View = System.Windows.Forms.View.Details;
            // 
            // button_ApplySetting
            // 
            this.button_ApplySetting.Location = new System.Drawing.Point(30, 216);
            this.button_ApplySetting.Name = "button_ApplySetting";
            this.button_ApplySetting.Size = new System.Drawing.Size(119, 23);
            this.button_ApplySetting.TabIndex = 5;
            this.button_ApplySetting.Text = "Apply Setting";
            this.button_ApplySetting.UseVisualStyleBackColor = true;
            this.button_ApplySetting.Click += new System.EventHandler(this.button_ApplySetting_Click);
            // 
            // button_RemoveFilter
            // 
            this.button_RemoveFilter.Location = new System.Drawing.Point(30, 130);
            this.button_RemoveFilter.Name = "button_RemoveFilter";
            this.button_RemoveFilter.Size = new System.Drawing.Size(119, 23);
            this.button_RemoveFilter.TabIndex = 4;
            this.button_RemoveFilter.Text = "Remove Filter Rule";
            this.button_RemoveFilter.UseVisualStyleBackColor = true;
            this.button_RemoveFilter.Click += new System.EventHandler(this.button_RemoveFilter_Click);
            // 
            // button_AddFilterRule
            // 
            this.button_AddFilterRule.Location = new System.Drawing.Point(30, 44);
            this.button_AddFilterRule.Name = "button_AddFilterRule";
            this.button_AddFilterRule.Size = new System.Drawing.Size(119, 23);
            this.button_AddFilterRule.TabIndex = 1;
            this.button_AddFilterRule.Text = "Add Filter Rule";
            this.button_AddFilterRule.UseVisualStyleBackColor = true;
            this.button_AddFilterRule.Click += new System.EventHandler(this.button_AddFilterRule_Click);
            // 
            // tabPage_EventLog
            // 
            this.tabPage_EventLog.Controls.Add(this.listView_Message);
            this.tabPage_EventLog.Location = new System.Drawing.Point(4, 22);
            this.tabPage_EventLog.Name = "tabPage_EventLog";
            this.tabPage_EventLog.Padding = new System.Windows.Forms.Padding(3);
            this.tabPage_EventLog.Size = new System.Drawing.Size(1010, 492);
            this.tabPage_EventLog.TabIndex = 3;
            this.tabPage_EventLog.Text = "EventLog";
            this.tabPage_EventLog.UseVisualStyleBackColor = true;
            // 
            // listView_Message
            // 
            this.listView_Message.Activation = System.Windows.Forms.ItemActivation.OneClick;
            this.listView_Message.Dock = System.Windows.Forms.DockStyle.Fill;
            this.listView_Message.FullRowSelect = true;
            this.listView_Message.GridLines = true;
            this.listView_Message.HotTracking = true;
            this.listView_Message.HoverSelection = true;
            this.listView_Message.LabelEdit = true;
            this.listView_Message.Location = new System.Drawing.Point(3, 3);
            this.listView_Message.Name = "listView_Message";
            this.listView_Message.Size = new System.Drawing.Size(1004, 486);
            this.listView_Message.TabIndex = 0;
            this.listView_Message.UseCompatibleStateImageBehavior = false;
            this.listView_Message.View = System.Windows.Forms.View.Details;
            // 
            // FilterDemo
            // 
            this.AutoScaleDimensions = new System.Drawing.SizeF(6F, 13F);
            this.AutoScaleMode = System.Windows.Forms.AutoScaleMode.Font;
            this.ClientSize = new System.Drawing.Size(1018, 518);
            this.Controls.Add(this.TabPage);
            this.Name = "FilterDemo";
            this.StartPosition = System.Windows.Forms.FormStartPosition.CenterParent;
            this.Text = "Filter Demo";
            this.TabPage.ResumeLayout(false);
            this.tabPage_FilterMessage.ResumeLayout(false);
            this.splitContainer1.Panel1.ResumeLayout(false);
            this.splitContainer1.Panel2.ResumeLayout(false);
            this.splitContainer1.ResumeLayout(false);
            this.groupBox1.ResumeLayout(false);
            this.tabPage_Setting.ResumeLayout(false);
            this.splitContainer3.Panel1.ResumeLayout(false);
            this.splitContainer3.Panel2.ResumeLayout(false);
            this.splitContainer3.ResumeLayout(false);
            this.splitContainer4.Panel1.ResumeLayout(false);
            this.splitContainer4.Panel1.PerformLayout();
            this.splitContainer4.Panel2.ResumeLayout(false);
            this.splitContainer4.ResumeLayout(false);
            this.groupBox3.ResumeLayout(false);
            this.groupBox3.PerformLayout();
            this.tabPage_EventLog.ResumeLayout(false);
            this.ResumeLayout(false);

            //initialize config setting.
            this.InitConfig();
        }

        #endregion

        private System.Windows.Forms.TabControl TabPage;
        private System.Windows.Forms.TabPage tabPage_Setting;
        private System.Windows.Forms.TabPage tabPage_EventLog;
        private System.Windows.Forms.SplitContainer splitContainer3;
        private System.Windows.Forms.SplitContainer splitContainer4;
        private System.Windows.Forms.Button button_AddFilterRule;
        private System.Windows.Forms.TextBox textBox_ExcludePID;
        private System.Windows.Forms.TextBox textBox_ConnectionTimeout;
        private System.Windows.Forms.TextBox textBox_AccessFlag;
        private System.Windows.Forms.Label label4;
        private System.Windows.Forms.Label label3;
        private System.Windows.Forms.Label label2;
        private System.Windows.Forms.Label label1;
        private System.Windows.Forms.ListView listView_FilterRules;
        private System.Windows.Forms.GroupBox groupBox3;
        private System.Windows.Forms.Label label6;
        private System.Windows.Forms.Label label5;
        private System.Windows.Forms.ComboBox comboBox_FilterType;
        private System.Windows.Forms.Button button_AccessFlag;
        private System.Windows.Forms.TextBox textBox_FilterMask;
        private System.Windows.Forms.Button button_RemoveFilter;
        private System.Windows.Forms.TabPage tabPage_FilterMessage;
        private System.Windows.Forms.SplitContainer splitContainer1;
        private System.Windows.Forms.ListView listView_MessageInfo;
        private System.Windows.Forms.GroupBox groupBox1;
        private System.Windows.Forms.Button button_Clear;
        private System.Windows.Forms.Button button_Start;
        private System.Windows.Forms.Button button_Stop;
        private System.Windows.Forms.Button button_ExcludedPID;
        private System.Windows.Forms.Button button_ApplySetting;
        private System.Windows.Forms.ListView listView_Message;
        private System.Windows.Forms.TextBox textBox_ConnectionThreads;
        private System.Windows.Forms.Label label_ConnectionThreads;
        private System.Windows.Forms.Label label7;
        private System.Windows.Forms.TextBox textBox_ReparseMask;
        private System.Windows.Forms.Button button_RequestRegistration;
        private System.Windows.Forms.TextBox textBox_RequestRegistration;
        private System.Windows.Forms.Button button_UnInstallDriver;
        private System.Windows.Forms.Button button_InstallDriver;

    }
}

