﻿///////////////////////////////////////////////////////////////////////////////
//
//    (C) Copyright 2011 EaseVault Technologies Inc.
//    All Rights Reserved
//
//    This software is part of a licensed software product and may
//    only be used or copied in accordance with the terms of that license.
//
///////////////////////////////////////////////////////////////////////////////

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Runtime.InteropServices;
using System.Security.Principal;
using System.IO;
using System.Threading;

namespace CSharpDemo
{
    public class MessageInfo:IDisposable
    {
        ListView listView_Message = null;
        Thread messageThread = null;
        Queue<EaseFilter.MessageSendData> messageQueue = new Queue<EaseFilter.MessageSendData>();
        Boolean startedProcess = false;
        AutoResetEvent autoEvent = new AutoResetEvent(false);
        bool disposed = false;


        public MessageInfo(ListView lvMessage)
        {
            this.listView_Message = lvMessage;
            InitListView();
            messageThread = new Thread(new ThreadStart(ProcessMessage));
            messageThread.Start();
        }

        public void Dispose()
        {
            Dispose(true);
            GC.SuppressFinalize(this);
        }

        private void Dispose(bool disposing)
          {
              if (!this.disposed)
              {
              }

              startedProcess = false;
              autoEvent.Set();
              messageThread.Abort();
              disposed = true;
          }

        ~MessageInfo()
        {
            Dispose(false);
        }

        public void InitListView()
        {
            messageQueue.Clear();
            //init ListView control
            listView_Message.Clear();		//clear control
            //create column header for ListView
            listView_Message.Columns.Add("#", 40, System.Windows.Forms.HorizontalAlignment.Left);
            listView_Message.Columns.Add("Time", 70, System.Windows.Forms.HorizontalAlignment.Left);
            listView_Message.Columns.Add("UserName", 150, System.Windows.Forms.HorizontalAlignment.Left);
            listView_Message.Columns.Add("ProcessName", 70, System.Windows.Forms.HorizontalAlignment.Left);
            listView_Message.Columns.Add("ProcessId", 40, System.Windows.Forms.HorizontalAlignment.Left);
            listView_Message.Columns.Add("ThreadId", 40, System.Windows.Forms.HorizontalAlignment.Left);
            listView_Message.Columns.Add("FileObject", 40, System.Windows.Forms.HorizontalAlignment.Left);
            listView_Message.Columns.Add("FsContext", 40, System.Windows.Forms.HorizontalAlignment.Left);
            listView_Message.Columns.Add("MessageType", 150, System.Windows.Forms.HorizontalAlignment.Left);
            listView_Message.Columns.Add("FileName", 350, System.Windows.Forms.HorizontalAlignment.Left);
            listView_Message.Columns.Add("FileSize", 70, System.Windows.Forms.HorizontalAlignment.Left);
            listView_Message.Columns.Add("FileAttributes", 70, System.Windows.Forms.HorizontalAlignment.Left);
            listView_Message.Columns.Add("CreationTime", 150, System.Windows.Forms.HorizontalAlignment.Left);
            listView_Message.Columns.Add("LastWriteTime", 150, System.Windows.Forms.HorizontalAlignment.Left);
            listView_Message.Columns.Add("DesiredAccess", 200, System.Windows.Forms.HorizontalAlignment.Left);
            listView_Message.Columns.Add("Disposition", 120, System.Windows.Forms.HorizontalAlignment.Left);
            listView_Message.Columns.Add("ShareAccess", 150, System.Windows.Forms.HorizontalAlignment.Left);
            listView_Message.Columns.Add("CreateOptions", 200, System.Windows.Forms.HorizontalAlignment.Left);            
            listView_Message.Columns.Add("Create Result", 100, System.Windows.Forms.HorizontalAlignment.Left);
            listView_Message.Columns.Add("Status", 100, System.Windows.Forms.HorizontalAlignment.Left);
            listView_Message.Columns.Add("InfoClass", 100, System.Windows.Forms.HorizontalAlignment.Left);
            listView_Message.Columns.Add("Offset", 70, System.Windows.Forms.HorizontalAlignment.Left);
            listView_Message.Columns.Add("ReadOrWriteLength", 50, System.Windows.Forms.HorizontalAlignment.Left);
            listView_Message.Columns.Add("DataBufferLength", 50, System.Windows.Forms.HorizontalAlignment.Left);
            listView_Message.Columns.Add("DataBuffer", 100, System.Windows.Forms.HorizontalAlignment.Left);
        }

        void ProcessMessage()
        {
            EaseFilter.MessageSendData messageSend = new EaseFilter.MessageSendData();
            List<EaseFilter.MessageSendData> messageList = new List<EaseFilter.MessageSendData>();
            startedProcess = true;

            while (startedProcess)
            {
                if (messageQueue.Count == 0)
                {
                    autoEvent.WaitOne();
                }

                lock (messageQueue)
                {
                    messageList.Clear();
                    while (messageQueue.Count > 0)
                    {
                        messageSend = (EaseFilter.MessageSendData)messageQueue.Dequeue();
                        messageList.Add(messageSend);
                    }
                }

                DisplayFilterMessage(messageList);

            }

        }

        void DisplayFilterMessage(List<EaseFilter.MessageSendData> messageList)
        {
            try
            {
                int totalItems = messageList.Count;

                if (totalItems == 0)
                {
                    return;
                }

                ListViewItem[] itemList = new ListViewItem[totalItems];

                for (int i = 0; i< totalItems; i++)
                {
                    EaseFilter.MessageSendData messageSend = messageList[i];
                    ListViewItem lvItem = GetFilterMessage(messageSend);
                    itemList[i] = lvItem;

                }

                listView_Message.Items.AddRange(itemList);
                listView_Message.EnsureVisible(listView_Message.Items.Count - 1);
            }
            catch (Exception ex)
            {
                EventMessage.LogErrorMessage(ex.Message);
            }
        }


        ListViewItem GetFilterMessage(EaseFilter.MessageSendData messageSend)
        {
            ListViewItem lvItem = new ListViewItem();

            try
            {
                string userName = string.Empty;
                string strSid = string.Empty;

                IntPtr sidBuffer = Marshal.UnsafeAddrOfPinnedArrayElement(messageSend.Sid, 0);
                ConvertSidToUserNameAndStringSid(sidBuffer, out userName, out strSid);

                string processName = string.Empty;

                try
                {
                    System.Diagnostics.Process requestProcess = System.Diagnostics.Process.GetProcessById((int)messageSend.ProcessId);
                    processName = requestProcess.ProcessName;
                }
                catch (Exception ex)
                {
                    EventMessage.LogErrorMessage("Convert process id to process name failed." + ex.Message);
                    processName = ex.Message;
                }

                string[] listData = new string[listView_Message.Columns.Count];

                int col = 0;
                listData[col++] = messageSend.MessageId.ToString();
                listData[col++] = FormatDateTime(messageSend.TransactionTime);             
                listData[col++] = userName;
                listData[col++] = processName;
                listData[col++] = messageSend.ProcessId.ToString();
                listData[col++] = messageSend.ThreadId.ToString();
                listData[col++] = messageSend.FileObject.ToString("X");
                listData[col++] = messageSend.FsContext.ToString("X");
                listData[col++] = ((EaseFilter.MessageType)messageSend.MessageType).ToString();
                listData[col++] = messageSend.FileName;
                listData[col++] = messageSend.FileSize.ToString();
                listData[col++] = ((FileAttributes)messageSend.FileAttributes).ToString();
                listData[col++] = FormatDateTime(messageSend.CreationTime);
                listData[col++] = FormatDateTime(messageSend.LastWriteTime);

                if (((EaseFilter.MessageType)messageSend.MessageType == EaseFilter.MessageType.PRE_CREATE)
                    || ((EaseFilter.MessageType)messageSend.MessageType == EaseFilter.MessageType.POST_CREATE))
                {
                    listData[col++] = FormatDesiredAccess(messageSend.DesiredAccess);
                    listData[col++] = ((WinData.Disposition)messageSend.Disposition).ToString();
                    listData[col++] = ((WinData.ShareAccess)messageSend.SharedAccess).ToString();
                    listData[col++] = FormatCreateOptions(messageSend.CreateOptions);

                    if (messageSend.Status == (uint)NtStatus.Status.Success
                          && ((EaseFilter.MessageType)messageSend.MessageType == EaseFilter.MessageType.POST_CREATE))
                    {
                        //the create status is meaningful only when the status is succeeded.
                        listData[col++] = ((WinData.CreateStatus)messageSend.CreateStatus).ToString();
                    }
                    else
                    {
                        listData[col++] = string.Empty;
                    }
                }
                else
                {
                    listData[col++] = string.Empty;
                    listData[col++] = string.Empty;
                    listData[col++] = string.Empty;
                    listData[col++] = string.Empty;
                    listData[col++] = string.Empty;
                }
              
                listData[col++] = FormatStatus(messageSend.Status);
                listData[col++] = FormatInfoClass((EaseFilter.MessageType)messageSend.MessageType, messageSend.InfoClass);

                listData[col++] = messageSend.Offset.ToString();
                listData[col++] = messageSend.Length.ToString();
                listData[col++] = messageSend.DataBufferLength.ToString();
                listData[col++] = FormatDataBuffer((EaseFilter.MessageType)messageSend.MessageType,
                                                    (WinData.FileInfomationClass)messageSend.InfoClass,
                                                    messageSend.DataBufferLength,
                                                    messageSend.DataBuffer);

                lvItem = new ListViewItem(listData, 0);

                if (messageSend.Status > (uint)NtStatus.Status.Error)
                {
                    lvItem.BackColor = Color.LightGray;
                    lvItem.ForeColor = Color.Red;
                }
                else if (messageSend.Status > (uint)NtStatus.Status.Warning)
                {
                    lvItem.BackColor = Color.LightGray;
                    lvItem.ForeColor = Color.Yellow;
                }

              
            }
            catch (Exception ex)
            {
                EventMessage.LogErrorMessage("Add callback message failed." + ex.Message);
            }

            return lvItem;
        }

       public void AddMessage(EaseFilter.MessageSendData messageSend)
       {
           lock (messageQueue)
           {
               messageQueue.Enqueue(messageSend);
           }

           autoEvent.Set();

       }


        bool ConvertSidToUserNameAndStringSid(IntPtr sidBuffer, out string userName, out string userSid)
        {
            bool ret = true;

            IntPtr sidStringPtr = IntPtr.Zero;
            string sidString = string.Empty;

            userName = string.Empty;
            userSid = string.Empty;

            try
            {
                if (EaseFilter.ConvertSidToStringSid(sidBuffer, out sidStringPtr))
                {
                    sidString = Marshal.PtrToStringAuto(sidStringPtr);
                    SecurityIdentifier secIdentifier = new SecurityIdentifier(sidString);
                    IdentityReference reference = secIdentifier.Translate(typeof(NTAccount));
                    userName = reference.Value;
                    userSid = secIdentifier.ToString();
                }
                else
                {
                    string errorMessage = "Convert sid to sid string failed, error code:" + Marshal.GetLastWin32Error();
                    EventMessage.LogErrorMessage(errorMessage);
                }
            }
            catch (Exception ex)
            {
                string errorMessage = string.Format("Convert sid to user name got exception:{0}", ex.Message);
                EventMessage.LogErrorMessage(errorMessage);
                userName = errorMessage;
                ret = false;

            }
            finally
            {
                if (sidStringPtr != null && sidStringPtr != IntPtr.Zero)
                {
                    IntPtr res = EaseFilter.LocalFree(sidStringPtr);
                }
            }

            return ret;
        }

        string FormatDesiredAccess(uint desiredAccess)
        {
            string ret = string.Empty;

            foreach (WinData.DisiredAccess access in Enum.GetValues(typeof(WinData.DisiredAccess)))
            {
                if (access == (WinData.DisiredAccess)((uint)access & desiredAccess))
                {
                    ret += access.ToString() + "; ";
                }
            }

            return ret;
        }

        string FormatCreateOptions(uint createOptions)
        {
            string ret = string.Empty;

            foreach (WinData.CreateOptions option in Enum.GetValues(typeof(WinData.CreateOptions)))
            {
                if (option == (WinData.CreateOptions)((uint)option & createOptions))
                {
                    ret += option.ToString() + "; ";
                }
            }

            if (string.IsNullOrEmpty(ret))
            {
                ret = "(0x)" + createOptions.ToString("X");
            }

            return ret;
        }

        string FormatDateTime(long lDateTime)
        {
            try
            {
                if (0 == lDateTime)
                {
                    return "0";
                }

                DateTime dateTime = DateTime.FromFileTime(lDateTime);
                string ret = dateTime.ToShortDateString() + " " + dateTime.ToShortTimeString();
                return ret;
            }
            catch (Exception ex)
            {
                EventMessage.LogErrorMessage("FormatDateTime :" + lDateTime.ToString() + " failed." + ex.Message);
                return ex.Message;
            }
        }

        string FormatDataBuffer(EaseFilter.MessageType messageType, WinData.FileInfomationClass infoClass, uint dataLength, byte[] data)
        {
            string ret = string.Empty;

            try
            {
                switch (messageType)
                {
                    case EaseFilter.MessageType.PRE_SET_INFORMATION:
                    case EaseFilter.MessageType.POST_SET_INFORMATION:
                    case EaseFilter.MessageType.PRE_QUERY_INFORMATION:
                    case EaseFilter.MessageType.POST_QUERY_INFORMATION:
                        switch (infoClass)
                        {
                            case WinData.FileInfomationClass.FileRenameInformation:
                                {
                                    //destination name
                                    ret = "Destination name:" + Encoding.Unicode.GetString(data);
                                    break;
                                }
                            case WinData.FileInfomationClass.FileDispositionInformation:
                                {
                                    ret = "Delete file.";
                                    break;
                                }
                            case WinData.FileInfomationClass.FileEndOfFileInformation:
                                {
                                    long newFileSize = BitConverter.ToInt64(data, 0);
                                    ret = "Change file size to:" + newFileSize.ToString();
                                    break;
                                }
                            case WinData.FileInfomationClass.FileBasicInformation:
                                {
                                    WinData.FileBasicInformation basiInfo = new WinData.FileBasicInformation();
                                    GCHandle pinnedPacket = GCHandle.Alloc(data, GCHandleType.Pinned);
                                    basiInfo = (WinData.FileBasicInformation)Marshal.PtrToStructure(
                                        pinnedPacket.AddrOfPinnedObject(), typeof(WinData.FileBasicInformation));
                                    pinnedPacket.Free();

                                    ret = "creation time:" + FormatDateTime(basiInfo.CreationTime) + "  ";
                                    ret += "last access time:" + FormatDateTime(basiInfo.LastAccessTime) + "   ";
                                    ret += "last write time:" + FormatDateTime(basiInfo.LastWriteTime) + "   ";
                                    ret += "file attributes:" + ((FileAttributes)basiInfo.FileAttributes).ToString();
                                    break;
                                }

                            case WinData.FileInfomationClass.FileStandardInformation:
                                {
                                    WinData.FileStandardInformation standardInfo = new WinData.FileStandardInformation();
                                    GCHandle pinnedPacket = GCHandle.Alloc(data, GCHandleType.Pinned);
                                    standardInfo = (WinData.FileStandardInformation)Marshal.PtrToStructure(
                                        pinnedPacket.AddrOfPinnedObject(), typeof(WinData.FileStandardInformation));
                                    pinnedPacket.Free();

                                    ret = "File size:" + standardInfo.EndOfFile.ToString() + "   ";
                                    ret += "Allocation size:" + standardInfo.AllocationSize.ToString() + "   ";
                                    ret += "IsDirectory:" + standardInfo.Directory.ToString();
                                    break;
                                }
                            case WinData.FileInfomationClass.FileNetworkOpenInformation:
                                {
                                    WinData.FileNetworkInformation networkInfo = new WinData.FileNetworkInformation();
                                    GCHandle pinnedPacket = GCHandle.Alloc(data, GCHandleType.Pinned);
                                    networkInfo = (WinData.FileNetworkInformation)Marshal.PtrToStructure(
                                        pinnedPacket.AddrOfPinnedObject(), typeof(WinData.FileNetworkInformation));
                                    pinnedPacket.Free();

                                    ret = "creation time:" + FormatDateTime(networkInfo.CreationTime) + "   ";
                                    ret += "last access time:" + FormatDateTime(networkInfo.LastAccessTime) + "   ";
                                    ret += "last write time:" + FormatDateTime(networkInfo.LastWriteTime) + "   ";
                                    ret += "file size:" + networkInfo.FileSize.ToString() + "   ";
                                    ret += "file attributes:" + ((FileAttributes)networkInfo.FileAttributes).ToString();
                                    break;
                                }

                            case WinData.FileInfomationClass.FileInternalInformation:
                                {
                                    long fileId = BitConverter.ToInt64(data, 0);
                                    ret = "FileId: (0x)" + fileId.ToString("X");
                                    break;
                                }
                        }

                        break;
                }
            }
            catch (Exception ex)
            {
                EventMessage.LogErrorMessage("Format data failed." + ex.Message);
                ret = ex.Message;
            }

            return ret;
        }

        string FormatStatus(uint status)
        {
            string ret = string.Empty;

            foreach (NtStatus.Status ntStatus in Enum.GetValues(typeof(NtStatus.Status)))
            {
                if (status == (uint)ntStatus)
                {
                    ret = ntStatus.ToString() + "(0x" + status.ToString("X") + ")";
                }
            }

            if (string.IsNullOrEmpty(ret))
            {
                ret = "(0x" + status.ToString("X") + ")";
            }

            return ret;
        }

        string FormatInfoClass(EaseFilter.MessageType messageType, uint infoClass)
        {
            string ret = string.Empty;

            if (EaseFilter.MessageType.PRE_QUERY_SECURITY == messageType
                || EaseFilter.MessageType.PRE_SET_SECURITY == messageType
                || EaseFilter.MessageType.POST_QUERY_SECURITY == messageType
                || EaseFilter.MessageType.POST_SET_SECURITY == messageType)
            {
                ret = ((WinData.SecurityInformation)(infoClass)).ToString();
            }
            else if (infoClass > 0)
            {
                ret = ((WinData.FileInfomationClass)infoClass).ToString();
            }
            else
            {
                ret = string.Empty;
            }

            return ret;
        }


    }
}